@@ -17,6 +17,7 @@ guess_package=${guess_package%-kernel}
 export guess_package
 
 topdir=${MOD_TOPDIR:-/usr/src}
+aptget=${MA_APTCMD:-apt-get}
 
 if test -n "$MA_DEBUG" ; then
    set -x
@@ -203,7 +204,7 @@ unpack() {
 }
 
 download() {
-   action $ROOT_CMD apt-get $REINSTALL install $sourcepkg
+   action $ROOT_CMD $aptget $REINSTALL install $sourcepkg
 }
 
 # wipes the builddir
